@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2017, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -13,13 +12,9 @@ in a specified Python module.
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
-from bokeh.util.api import general, dev ; general, dev
-
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
@@ -28,23 +23,28 @@ from bokeh.util.api import general, dev ; general, dev
 import codecs
 import os
 
-# External imports
-
 # Bokeh imports
 from ...util.callback_manager import _check_callback
 from .code_runner import CodeRunner
-from .handler import Handler
+from .lifecycle import LifecycleHandler
 
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
 
+__all__ = (
+    'ServerLifecycleHandler',
+)
+
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
 
-@general((1,0,0))
-class ServerLifecycleHandler(Handler):
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
+class ServerLifecycleHandler(LifecycleHandler):
     ''' Load a script which contains server lifecycle callbacks.
 
     '''
@@ -59,21 +59,17 @@ class ServerLifecycleHandler(Handler):
                 ``sys.argv`` when the callback code is executed. (default: [])
 
         '''
-        super(ServerLifecycleHandler, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         if 'filename' not in kwargs:
             raise ValueError('Must pass a filename to ServerLifecycleHandler')
         filename = kwargs['filename']
         argv = kwargs.get('argv', [])
+        package = kwargs.get('package', False)
 
         source = codecs.open(filename, 'r', 'UTF-8').read()
 
-        self._runner = CodeRunner(source, filename, argv)
-
-        self._on_server_loaded = _do_nothing
-        self._on_server_unloaded = _do_nothing
-        self._on_session_created = _do_nothing
-        self._on_session_destroyed = _do_nothing
+        self._runner = CodeRunner(source, filename, argv, package=package)
 
         if not self._runner.failed:
             # unlike ScriptHandler, we only load the module one time
@@ -100,7 +96,6 @@ class ServerLifecycleHandler(Handler):
     # Properties --------------------------------------------------------------
 
     @property
-    @general((1,0,0))
     def error(self):
         ''' If the handler fails, may contain a related error message.
 
@@ -108,7 +103,6 @@ class ServerLifecycleHandler(Handler):
         return self._runner.error
 
     @property
-    @general((1,0,0))
     def error_detail(self):
         ''' If the handler fails, may contain a traceback or other details.
 
@@ -116,7 +110,6 @@ class ServerLifecycleHandler(Handler):
         return self._runner.error_detail
 
     @property
-    @general((1,0,0))
     def failed(self):
         ''' ``True`` if the lifecycle callbacks failed to execute
 
@@ -125,72 +118,6 @@ class ServerLifecycleHandler(Handler):
 
     # Public methods ----------------------------------------------------------
 
-    @general((1,0,0))
-    def modify_document(self, doc):
-        ''' This handler does not make any modifications to the Document.
-
-        Args:
-            doc (Document) : A Bokeh Document to update in-place
-
-                *This handler does not modify the document*
-
-        Returns:
-            None
-
-        '''
-        # we could support a modify_document function, might be weird though.
-        pass
-
-    @general((1,0,0))
-    def on_server_loaded(self, server_context):
-        ''' Execute `on_server_unloaded`` from the configured module (if
-        it is defined) when the server is first started.
-
-        Args:
-            server_context (ServerContext) :
-
-        '''
-        return self._on_server_loaded(server_context)
-
-    @general((1,0,0))
-    def on_server_unloaded(self, server_context):
-        ''' Execute ``on_server_unloaded`` from the configured module (if
-        it is defined) when the server cleanly exits. (Before stopping the
-        server's ``IOLoop``.)
-
-        Args:
-            server_context (ServerContext) :
-
-        .. warning::
-            In practice this code may not run, since servers are often killed
-            by a signal.
-
-        '''
-        return self._on_server_unloaded(server_context)
-
-    @general((1,0,0))
-    def on_session_created(self, session_context):
-        ''' Execute ``on_session_created`` from the configured module (if
-        it is defined) when a new session is created.
-
-        Args:
-            session_context (SessionContext) :
-
-        '''
-        return self._on_session_created(session_context)
-
-    @general((1,0,0))
-    def on_session_destroyed(self, session_context):
-        ''' Execute ``on_session_destroyed`` from the configured module (if
-        it is defined) when a new session is destroyed.
-
-        Args:
-            session_context (SessionContext) :
-
-        '''
-        return self._on_session_destroyed(session_context)
-
-    @general((1,0,0))
     def url_path(self):
         ''' The last path component for the basename of the path to the
         callback module.
@@ -202,17 +129,10 @@ class ServerLifecycleHandler(Handler):
             # TODO should fix invalid URL characters
             return '/' + os.path.splitext(os.path.basename(self._runner.path))[0]
 
-#-----------------------------------------------------------------------------
-# Dev API
-#-----------------------------------------------------------------------------
-
 #-----------------------------------------------------------------------------
 # Private API
 #-----------------------------------------------------------------------------
 
-def _do_nothing(ignored):
-    pass
-
 #-----------------------------------------------------------------------------
 # Code
 #-----------------------------------------------------------------------------
