@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -203,7 +203,7 @@ variable ``BOKEH_SSL_CERTFILE``.
 
 If the private key is stored separately, its location may be supplied by
 setting the ``--ssl-keyfile`` command line argument, or by setting the
-``BOKEH_SSL_KEYFILE`` evironment variable. If a password is required for the
+``BOKEH_SSL_KEYFILE`` environment variable. If a password is required for the
 private key, it should be supplied by setting the ``BOKEH_SSL_PASSWORD``
 environment variable.
 
@@ -245,7 +245,7 @@ secure session IDs are allowed but anyone can connect to the server.
 In ``external-signed`` mode, the session ID must be signed but the server
 itself won't generate a session ID; the ``?bokeh-session-id=`` parameter will
 be required. To use this mode, an external process (such as another web app)
-would use the function ``bokeh.util.session_id.generate_session_id()`` to
+would use the function ``bokeh.util.token.generate_session_id()`` to
 create valid session IDs. The external process and the Bokeh server must share
 the same ``BOKEH_SECRET_KEY`` environment variable.
 
@@ -400,9 +400,7 @@ logging stats is 0 (disabled). Only positive integer values are accepted.
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
@@ -411,9 +409,10 @@ log = logging.getLogger(__name__)
 
 # Standard library imports
 import argparse
-from fnmatch import fnmatch
 import os
+from fnmatch import fnmatch
 from glob import glob
+from typing import Any, Dict, List
 
 # External imports
 from tornado.autoreload import watch
@@ -421,23 +420,27 @@ from tornado.autoreload import watch
 # Bokeh imports
 from bokeh.application import Application
 from bokeh.resources import DEFAULT_SERVER_PORT
-from bokeh.util.logconfig import basicConfig
-from bokeh.util.string import nice_join, format_docstring
 from bokeh.server.auth_provider import AuthModule, NullAuth
-from bokeh.server.tornado import DEFAULT_WEBSOCKET_MAX_MESSAGE_SIZE_BYTES
+from bokeh.server.tornado import (
+    DEFAULT_SESSION_TOKEN_EXPIRATION,
+    DEFAULT_WEBSOCKET_MAX_MESSAGE_SIZE_BYTES,
+)
 from bokeh.settings import settings
+from bokeh.util.logconfig import basicConfig
+from bokeh.util.string import format_docstring, nice_join
 
+# Bokeh imports
 from ..subcommand import Subcommand
 from ..util import build_single_handler_applications, die, report_server_init_errors
 
-LOGLEVELS = ('trace', 'debug', 'info', 'warning', 'error', 'critical')
-SESSION_ID_MODES = ('unsigned', 'signed', 'external-signed')
-DEFAULT_LOG_FORMAT = "%(asctime)s %(message)s"
-
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
 
+LOGLEVELS = ('trace', 'debug', 'info', 'warning', 'error', 'critical')
+SESSION_ID_MODES = ('unsigned', 'signed', 'external-signed')
+DEFAULT_LOG_FORMAT = "%(asctime)s %(message)s"
+
 base_serve_args = (
     ('--port', dict(
         metavar = 'PORT',
@@ -457,7 +460,7 @@ base_serve_args = (
         metavar = 'LOG-LEVEL',
         action  = 'store',
         default = None,
-        choices = LOGLEVELS + (None,),
+        choices = LOGLEVELS + ("None", ),
         help    = "One of: %s" % nice_join(LOGLEVELS),
     )),
 
@@ -633,6 +636,38 @@ class Serve(Subcommand):
                       'when this setting is enabled.'
         )),
 
+        ('--exclude-headers', dict(
+            action  = 'store',
+            default = None,
+            nargs='+',
+            help    = 'A list of request headers to exclude from the session '
+                      'context (by default all headers are included).'
+        )),
+
+        ('--exclude-cookies', dict(
+            action  = 'store',
+            default = None,
+            nargs='+',
+            help    = 'A list of request cookies to exclude from the session '
+                      'context (by default all cookies are included).'
+        )),
+
+        ('--include-headers', dict(
+            action  = 'store',
+            default = None,
+            nargs='+',
+            help    = 'A list of request headers to make available in the session '
+                      'context (by default all headers are included).'
+        )),
+
+        ('--include-cookies', dict(
+            action  = 'store',
+            default = None,
+            nargs='+',
+            help    = 'A list of request cookies to make available in the session '
+                      'context (by default all cookies are included).'
+        )),
+
         ('--cookie-secret', dict(
             metavar = 'COOKIE_SECRET',
             action  = 'store',
@@ -666,22 +701,56 @@ class Serve(Subcommand):
             type    = int,
         )),
 
+        ('--session-token-expiration', dict(
+            metavar = 'N',
+            action  = 'store',
+            help    = "Duration in seconds that a new session token "
+                      "is valid for session creation. After the expiry "
+                      "time has elapsed, the token will not be able "
+                      "create a new session (defaults to  seconds).",
+            default = DEFAULT_SESSION_TOKEN_EXPIRATION,
+            type    = int,
+        )),
+
         ('--websocket-max-message-size', dict(
             metavar = 'BYTES',
             action  = 'store',
-            help    = "Set the Tornado websocket_max_message_size value (defaults "
-                      "to 20MB) NOTE: This setting has effect ONLY for Tornado>=4.5",
+            help    = "Set the Tornado websocket_max_message_size value "
+                      "(default: 20MB)",
             default = DEFAULT_WEBSOCKET_MAX_MESSAGE_SIZE_BYTES,
             type    = int,
         )),
 
+        ('--websocket-compression-level', dict(
+            metavar = 'LEVEL',
+            action  = 'store',
+            help    = "Set the Tornado WebSocket compression_level",
+            default = None,
+            type    = int,
+        )),
+
+        ('--websocket-compression-mem-level', dict(
+            metavar = 'LEVEL',
+            action  = 'store',
+            help    = "Set the Tornado WebSocket compression mem_level",
+            default = None,
+            type    = int,
+        )),
+
         ('--glob', dict(
             action='store_true',
-            help='Process all filenames as globs',
+            help='Process all filename arguments as globs',
         )),
     )
 
-    def invoke(self, args):
+    def customize_kwargs(self, args: argparse.Namespace, server_kwargs: Dict[str, Any]) -> Dict[str, Any]:
+        '''Allows subclasses to customize ``server_kwargs``.
+
+        Should modify and return a copy of the ``server_kwargs`` dictionary.
+        '''
+        return dict(server_kwargs)
+
+    def invoke(self, args: argparse.Namespace) -> None:
         '''
 
         '''
@@ -696,7 +765,7 @@ class Serve(Subcommand):
         logging.getLogger('bokeh').setLevel(log_level)
 
         if args.use_config is not None:
-            log.info("Using override config file: {}".format(args.use_config))
+            log.info(f"Using override config file: {args.use_config}")
             settings.load_config(args.use_config)
 
         # protect this import inside a function so that "bokeh info" can work
@@ -746,6 +815,13 @@ class Serve(Subcommand):
                                                               'mem_log_frequency_milliseconds',
                                                               'use_xheaders',
                                                               'websocket_max_message_size',
+                                                              'websocket_compression_level',
+                                                              'websocket_compression_mem_level',
+                                                              'include_cookies',
+                                                              'include_headers',
+                                                              'exclude_cookies',
+                                                              'exclude_headers',
+                                                              'session_token_expiration',
                                                             ]
                           if getattr(args, key, None) is not None }
 
@@ -785,7 +861,7 @@ class Serve(Subcommand):
         server_kwargs['redirect_root'] = not args.disable_index_redirect
         server_kwargs['autoreload'] = args.dev is not None
 
-        def find_autoreload_targets(app_path):
+        def find_autoreload_targets(app_path: str) -> None:
             path = os.path.abspath(app_path)
             if not os.path.isdir(path):
                 return
@@ -798,7 +874,7 @@ class Serve(Subcommand):
                         log.info("Watching: " + os.path.join(path, name))
                         watch(os.path.join(path, name))
 
-        def add_optional_autoreload_files(file_list):
+        def add_optional_autoreload_files(file_list: List[str]) -> None:
             for filen in file_list:
                 if os.path.isdir(filen):
                     log.warning("Cannot watch directory " + filen)
@@ -816,13 +892,15 @@ class Serve(Subcommand):
             find_autoreload_targets(args.files[0])
             add_optional_autoreload_files(args.dev)
 
+        server_kwargs = self.customize_kwargs(args, server_kwargs)
+
         with report_server_init_errors(**server_kwargs):
             server = Server(applications, **server_kwargs)
 
             if args.show:
 
                 # we have to defer opening in browser until we start up the server
-                def show_callback():
+                def show_callback() -> None:
                     for route in applications.keys():
                         server.show(route)
 
@@ -851,8 +929,8 @@ class Serve(Subcommand):
 # Code
 #-----------------------------------------------------------------------------
 
-
-__doc__ = format_docstring(__doc__,
+# XXX fails mypy typechecking with "error: Incompatible types in assignment (expression has type "Optional[str]", variable has type "str")"
+__doc__ = format_docstring(__doc__, # type: ignore
     DEFAULT_PORT=DEFAULT_SERVER_PORT,
     LOGLEVELS=nice_join(LOGLEVELS),
     SESSION_ID_MODES=nice_join(SESSION_ID_MODES),
