@@ -1,13 +1,13 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
+# Copyright (c) 2012 - 2021, Anaconda, Inc. All rights reserved.
 #
 # Powered by the Bokeh Development Team.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
-''' Provide the Struct property.
+""" Provide the Struct property.
 
-'''
+"""
 
 #-----------------------------------------------------------------------------
 # Boilerplate
@@ -35,10 +35,10 @@ __all__ = (
 #-----------------------------------------------------------------------------
 
 class Struct(ParameterizedProperty):
-    ''' Accept values that are structures.
+    """ Accept values that are structures.
 
 
-    '''
+    """
     def __init__(self, **fields):
         default = fields.pop("default", None)
         help = fields.pop("help", None)
@@ -56,22 +56,21 @@ class Struct(ParameterizedProperty):
     def validate(self, value, detail=True):
         super().validate(value, detail)
 
-        if value is None:
-            return
-
         if isinstance(value, dict) and len(value) <= len(self._fields):
+            # note use of for-else loop here
             for name, type in self._fields.items():
                 if not type.is_valid(value.get(name, None)):
                     break
             else:
                 return
 
-        msg = "" if not detail else "expected an element of %s, got %r" % (self, value)
+        msg = "" if not detail else f"expected an element of {self}, got {value!r}"
         raise ValueError(msg)
 
     def __str__(self):
-        fields = [ "%s=%s" % (name, type) for name, type in self._fields.items() ]
-        return "%s(%s)" % (self.__class__.__name__, ", ".join(fields))
+        class_name = self.__class__.__name__
+        fields = ", ".join(f"{name}={typ}" for name, typ in self._fields.items())
+        return f"{class_name}({fields})"
 
 #-----------------------------------------------------------------------------
 # Dev API
