@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -47,6 +47,20 @@ different usage, for more information see the docs for |Include|.
 .. |LineProps| replace:: :class:`~bokeh.core.property_mixins.LineProps`
 .. |TextProps| replace:: :class:`~bokeh.core.property_mixins.TextProps`
 
+.. |miter_join| image:: /_images/miter_join.png
+    :height: 15
+.. |round_join| image:: /_images/round_join.png
+    :height: 15
+.. |bevel_join| image:: /_images/bevel_join.png
+    :height: 15
+
+.. |butt_cap| image:: /_images/butt_cap.png
+    :height: 12
+.. |round_cap| image:: /_images/round_cap.png
+    :height: 12
+.. |square_cap| image:: /_images/square_cap.png
+    :height: 12
+
 '''
 #-----------------------------------------------------------------------------
 # Boilerplate
@@ -70,22 +84,31 @@ from .enums import (
 )
 from .has_props import HasProps
 from .properties import (
+    Alpha,
+    AlphaSpec,
     Color,
     ColorSpec,
     DashPattern,
+    DashPatternSpec,
     Dict,
     Enum,
     Float,
     FontSize,
     FontSizeSpec,
+    FontStyleSpec,
     HatchPatternSpec,
-    Include,
+    IntSpec,
+    LineCapSpec,
+    LineJoinSpec,
     Instance,
     Int,
+    Nullable,
     NumberSpec,
-    Percent,
     Size,
     String,
+    StringSpec,
+    TextAlignSpec,
+    TextBaselineSpec,
     value,
 )
 
@@ -110,147 +133,86 @@ __all__ = (
 
 _color_help = """
 A color to use to %s with.
-
-Acceptable values are:
-
-- any of the 147 named `CSS colors`_, e.g ``'green'``, ``'indigo'``
-- an RGB(A) hex value, e.g., ``'#FF0000'``, ``'#44444444'``
-- a 3-tuple of integers (r,g,b) between 0 and 255
-- a 4-tuple of (r,g,b,a) where r,g,b are integers between 0..255 and a is between 0..1
-
-.. _CSS colors: https://www.w3schools.com/colors/colors_names.asp
-
 """
 
 _alpha_help = """
 An alpha value to use to %s with.
+"""
 
-Acceptable values are floating point numbers between 0 (transparent)
-and 1 (opaque).
+_line_width_help = """
+Stroke width in units of pixels.
+"""
+
+_line_join_help = """
+How path segments should be joined together.
+
+Acceptable values are:
+
+- ``'miter'`` |miter_join|
+- ``'round'`` |round_join|
+- ``'bevel'`` |bevel_join|
 
 """
 
-class _BaseLineProps(HasProps):
-    line_join = Enum(LineJoin, default='bevel', help="""
-    How path segments should be joined together.
+_line_cap_help = """
+How path segments should be terminated.
 
-    Acceptable values are:
+Acceptable values are:
 
-    - ``'miter'`` |miter_join|
-    - ``'round'`` |round_join|
-    - ``'bevel'`` |bevel_join|
+- ``'butt'`` |butt_cap|
+- ``'round'`` |round_cap|
+- ``'square'`` |square_cap|
 
-    .. |miter_join| image:: /_images/miter_join.png
-       :height: 15
-    .. |round_join| image:: /_images/round_join.png
-       :height: 15
-    .. |bevel_join| image:: /_images/bevel_join.png
-       :height: 15
+"""
 
-    """)
+_text_font_help = """
+Name of a font to use for rendering text, e.g., ``'times'``, ``'helvetica'``.
 
-    line_cap = Enum(LineCap, help="""
-    How path segments should be terminated.
+"""
 
-    Acceptable values are:
+_text_font_style_help = """
+A style to use for rendering text.
 
-    - ``'butt'`` |butt_cap|
-    - ``'round'`` |round_cap|
-    - ``'square'`` |square_cap|
+Acceptable values are:
 
-    .. |butt_cap| image:: /_images/butt_cap.png
-       :height: 12
-    .. |round_cap| image:: /_images/round_cap.png
-       :height: 12
-    .. |square_cap| image:: /_images/square_cap.png
-       :height: 12
+- ``'normal'`` normal text
+- ``'italic'`` *italic text*
+- ``'bold'`` **bold text**
+- ``"bold italic"`` ***bold italic text***
 
-    """)
+"""
 
-    line_dash = DashPattern(help="""
-    How should the line be dashed.
-    """)
+_text_align_help = """
+Horizontal anchor point to use when rendering text.
 
-    line_dash_offset = Int(0, help="""
-    The distance into the ``line_dash`` (in pixels) that the pattern should
-    start from.
-    """)
+Acceptable values are:
 
-class _BaseTextProps(HasProps):
+- ``'left'``
+- ``'right'``
+- ``'center'``
 
-    text_font = String("helvetica", help="""
-    Name of a font to use for rendering text, e.g., ``'times'``,
-    ``'helvetica'``.
+"""
 
-    """)
+_text_baseline_help = """
+Vertical anchor point to use when rendering text.
 
-    text_font_style = Enum(FontStyle, help="""
-    A style to use for rendering text.
+Acceptable values are:
 
-    Acceptable values are:
+- ``'top'``
+- ``'middle'``
+- ``'bottom'``
+- ``'alphabetic'``
+- ``'hanging'``
+- ``'ideographic'``
 
-    - ``'normal'`` normal text
-    - ``'italic'`` *italic text*
-    - ``'bold'`` **bold text**
-    - ``"bold italic"`` ***bold italic text***
+"""
 
-    """)
-
-    text_align = Enum(TextAlign, help="""
-    Horizontal anchor point to use when rendering text.
-
-    Acceptable values are:
-
-    - ``'left'``
-    - ``'right'``
-    - ``'center'``
-
-    """)
-
-    text_baseline = Enum(TextBaseline, default="bottom", help="""
-    Vertical anchor point to use when rendering text.
-
-    Acceptable values are:
-
-    - ``'top'``
-    - ``'middle'``
-    - ``'bottom'``
-    - ``'alphabetic'``
-    - ``'hanging'``
-    - ``'ideographic'``
-
-    """)
-
-    text_line_height = Float(default=1.2, help="""
-    In multi-line text, how much additional space should be allocated for
-    each line. The value is provided as a number, but should be treated as
-    a percentage of font size. The default is 120%. Setting it to 1.0, so
-    100%, means no additional space will be used.
-    """)
-
-#----------------------------------------------------------------------------
-# General API
-#----------------------------------------------------------------------------
-
-class FillProps(HasProps):
-    ''' Properties relevant to rendering fill regions.
-
-    Mirrors the BokehJS ``properties.Fill`` class.
-
-    '''
-
-    fill_color = ColorSpec(default="gray", help=_color_help % "fill paths")
-    fill_alpha = NumberSpec(default=1.0, accept_datetime=False, accept_timedelta=False, help=_alpha_help % "fill paths")
-
-class ScalarFillProps(HasProps):
-    ''' Properties relevant to rendering fill regions.
-
-    Mirrors the BokehJS ``properties.Fill`` class.
-
-    '''
-
-    fill_color = Color(default="gray", help=_color_help  % "fill paths")
-    fill_alpha = Percent(default=1.0, help=_alpha_help)
+_text_line_height_help = """
+In multi-line text, how much additional space should be allocated for
+each line. The value is provided as a number, but should be treated as
+a percentage of font size. The default is 120%. Setting it to 1.0, so
+100%, means no additional space will be used.
+"""
 
 _hatch_scale_help = """
 A rough measure of the 'size' of the hatching pattern. Generally speaking, the
@@ -271,15 +233,39 @@ _hatch_weight_help = """
 A width value for line-strokes used in hatching.
 """
 
+#----------------------------------------------------------------------------
+# General API
+#----------------------------------------------------------------------------
+
+class FillProps(HasProps):
+    ''' Properties relevant to rendering fill regions.
+
+    Mirrors the BokehJS ``properties.FillVector`` class.
+
+    '''
+
+    fill_color = ColorSpec(default="gray", help=_color_help % "fill paths")
+    fill_alpha = AlphaSpec(help=_alpha_help % "fill paths")
+
+class ScalarFillProps(HasProps):
+    ''' Properties relevant to rendering fill regions.
+
+    Mirrors the BokehJS ``properties.Fill`` class.
+
+    '''
+
+    fill_color = Nullable(Color, default="gray", help=_color_help  % "fill paths")
+    fill_alpha = Alpha(help=_alpha_help)
+
 class HatchProps(HasProps):
     ''' Properties relevant to rendering fill regions.
 
-    Mirrors the BokehJS ``properties.Hatch`` class.
+    Mirrors the BokehJS ``properties.HatchVector`` class.
 
     '''
 
     hatch_color = ColorSpec(default="black", help=_color_help % "hatching")
-    hatch_alpha = NumberSpec(default=1.0, accept_datetime=False, accept_timedelta=False, help=_alpha_help % "hatching")
+    hatch_alpha = AlphaSpec(help=_alpha_help % "hatching")
     hatch_scale = NumberSpec(default=12.0, accept_datetime=False, accept_timedelta=False, help=_hatch_scale_help)
     hatch_pattern = HatchPatternSpec(default=None, help=_hatch_pattern_help)
     hatch_weight = NumberSpec(default=1.0, accept_datetime=False, accept_timedelta=False, help=_hatch_weight_help)
@@ -292,29 +278,27 @@ class ScalarHatchProps(HasProps):
 
     '''
 
-    hatch_color = Color(default="black", help=_color_help % "hatching")
-    hatch_alpha = Percent(default=1.0, help=_alpha_help % "hatching")
+    hatch_color = Nullable(Color, default="black", help=_color_help % "hatching")
+    hatch_alpha = Alpha(help=_alpha_help % "hatching")
     hatch_scale = Size(default=12.0, help=_hatch_scale_help)
-    hatch_pattern = String(default=None, help=_hatch_pattern_help)  # String to accommodate user custom values
+    hatch_pattern = Nullable(String, help=_hatch_pattern_help)  # String to accommodate user custom values
     hatch_weight = Size(default=1.0, help=_hatch_weight_help)
     hatch_extra = Dict(String, Instance("bokeh.models.textures.Texture"))
 
-_line_width_help = """
-Stroke width in units of pixels.
-"""
-
 class LineProps(HasProps):
     ''' Properties relevant to rendering path operations.
 
-    Mirrors the BokehJS ``properties.Line`` class.
+    Mirrors the BokehJS ``properties.LineVector`` class.
 
     '''
 
-    base_line_props = Include(_BaseLineProps, use_prefix=False)
-
     line_color = ColorSpec(default="black", help=_color_help % "stroke paths")
+    line_alpha = AlphaSpec(help=_alpha_help % "stroke paths")
     line_width = NumberSpec(default=1, accept_datetime=False, accept_timedelta=False, help=_line_width_help)
-    line_alpha = NumberSpec(default=1.0, accept_datetime=False, accept_timedelta=False, help=_alpha_help % "stroke paths")
+    line_join = LineJoinSpec(default="bevel", help=_line_join_help)
+    line_cap = LineCapSpec(default="butt", help=_line_cap_help)
+    line_dash = DashPatternSpec(default=[], help="""How should the line be dashed.""")
+    line_dash_offset = IntSpec(default=0, help="""The distance into the ``line_dash`` (in pixels) that the pattern should start from.""")
 
 
 class ScalarLineProps(HasProps):
@@ -323,30 +307,35 @@ class ScalarLineProps(HasProps):
     Mirrors the BokehJS ``properties.Line`` class.
 
     '''
-    base_line_props = Include(_BaseLineProps, use_prefix=False)
 
-    line_color = Color(default="black", help=_color_help % "stroke paths")
+    line_color = Nullable(Color, default="black", help=_color_help % "stroke paths")
+    line_alpha = Alpha(help=_alpha_help % "stroke paths")
     line_width = Float(default=1, help=_line_width_help)
-    line_alpha = Percent(default=1.0, help=_alpha_help % "stroke paths")
+    line_join = Enum(LineJoin, default="bevel", help=_line_join_help)
+    line_cap = Enum(LineCap, default="butt", help=_line_cap_help)
+    line_dash = DashPattern(default=[], help="""How should the line be dashed.""")
+    line_dash_offset = Int(default=0, help="""The distance into the ``line_dash`` (in pixels) that the pattern should start from.""")
 
 
 class TextProps(HasProps):
     ''' Properties relevant to rendering text.
 
-    Mirrors the BokehJS ``properties.Text`` class.
+    Mirrors the BokehJS ``properties.TextVector`` class.
 
     .. note::
         There is currently only support for filling text. An interface
         to stroke the outlines of text has not yet been exposed.
 
     '''
-    base_text_props = Include(_BaseTextProps, use_prefix=False)
-
-    text_font_size = FontSizeSpec(value("16px"))
 
     text_color = ColorSpec(default="#444444", help=_color_help % "fill text")
-
-    text_alpha = NumberSpec(default=1.0, accept_datetime=False, accept_timedelta=False, help=_alpha_help % "fill text")
+    text_alpha = AlphaSpec(help=_alpha_help % "fill text")
+    text_font = StringSpec(default=value("helvetica"), help=_text_font_help)
+    text_font_size = FontSizeSpec(default=value("16px"))
+    text_font_style = FontStyleSpec(default="normal", help=_text_font_style_help)
+    text_align = TextAlignSpec(default="left", help=_text_align_help)
+    text_baseline = TextBaselineSpec(default="bottom", help=_text_baseline_help)
+    text_line_height = NumberSpec(default=1.2, help=_text_line_height_help)
 
 class ScalarTextProps(HasProps):
     ''' Properties relevant to rendering text.
@@ -359,14 +348,14 @@ class ScalarTextProps(HasProps):
 
     '''
 
-    base_text_props = Include(_BaseTextProps, use_prefix=False)
-
-    # XXX not great
-    text_font_size = FontSize("16px")
-
-    text_color = Color(default="#444444", help=_color_help % "fill text")
-
-    text_alpha = Percent(default=1.0, help=_alpha_help % "fill text")
+    text_color = Nullable(Color, default="#444444", help=_color_help % "fill text")
+    text_alpha = Alpha(help=_alpha_help % "fill text")
+    text_font = String(default="helvetica", help=_text_font_help)
+    text_font_size = FontSize("16px") # XXX not great XXX why?
+    text_font_style = Enum(FontStyle, default="normal", help=_text_font_style_help)
+    text_align = Enum(TextAlign, default="left", help=_text_align_help)
+    text_baseline = Enum(TextBaseline, default="bottom", help=_text_baseline_help)
+    text_line_height = Float(default=1.2, help=_text_line_height_help)
 
 #-----------------------------------------------------------------------------
 # Dev API
