@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -11,9 +11,7 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
@@ -21,19 +19,26 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-from bokeh.util.future import collections_abc # goes away with py2
+from typing import Any, Dict, Optional, Sequence, Tuple, Type, Union, cast
 
 # External imports
-from six import string_types
+from jinja2 import Template
 
 # Bokeh imports
-from ..core.templates import AUTOLOAD_JS, AUTOLOAD_TAG, FILE, ROOT_DIV, MACROS
+from ..core.templates import AUTOLOAD_JS, AUTOLOAD_TAG, FILE, MACROS, ROOT_DIV
 from ..document.document import DEFAULT_TITLE, Document
 from ..model import Model
-from ..util.string import encode_utf8
-from .bundle import bundle_for_objs_and_resources, Script
+from ..resources import CSSResources, JSResources, Resources
+from ..themes import Theme
+from .bundle import Script, bundle_for_objs_and_resources
 from .elements import html_page_for_render_items, script_for_render_items
-from .util import FromCurdoc, OutputDocumentFor, standalone_docs_json, standalone_docs_json_and_render_items
+from .util import (
+    FromCurdoc,
+    OutputDocumentFor,
+    RenderRoot,
+    standalone_docs_json,
+    standalone_docs_json_and_render_items,
+)
 from .wrappers import wrap_in_onload
 
 #-----------------------------------------------------------------------------
@@ -47,11 +52,16 @@ __all__ = (
     'json_item',
 )
 
+ModelLike = Union[Model, Document]
+ModelLikeCollection = Union[Sequence[ModelLike], Dict[str, ModelLike]]
+
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
 
-def autoload_static(model, resources, script_path):
+ThemeLike = Union[None, Theme, Type[FromCurdoc]]
+
+def autoload_static(model: Union[Model, Document], resources: Resources, script_path: str) -> Tuple[str, str]:
     ''' Return JavaScript code and a script tag that can be used to embed
     Bokeh Plots.
 
@@ -99,9 +109,10 @@ def autoload_static(model, resources, script_path):
         elementid = elementid,
     )
 
-    return encode_utf8(js), encode_utf8(tag)
+    return js, tag
 
-def components(models, wrap_script=True, wrap_plot_info=True, theme=FromCurdoc):
+def components(models: Union[ModelLike, ModelLikeCollection], wrap_script: bool = True,
+               wrap_plot_info: bool = True, theme: ThemeLike = None) -> Tuple[str, Any]:
     ''' Return HTML components to embed a Bokeh plot. The data for the plot is
     stored directly in the returned HTML.
 
@@ -114,9 +125,9 @@ def components(models, wrap_script=True, wrap_plot_info=True, theme=FromCurdoc):
 
     .. code-block:: html
 
-        <script src="https://cdn.pydata.org/bokeh/release/bokeh-x.y.z.min.js"></script>
-        <script src="https://cdn.pydata.org/bokeh/release/bokeh-widgets-x.y.z.min.js"></script>
-        <script src="https://cdn.pydata.org/bokeh/release/bokeh-tables-x.y.z.min.js"></script>
+        <script src="https://cdn.bokeh.org/bokeh/release/bokeh-x.y.z.min.js"></script>
+        <script src="https://cdn.bokeh.org/bokeh/release/bokeh-widgets-x.y.z.min.js"></script>
+        <script src="https://cdn.bokeh.org/bokeh/release/bokeh-tables-x.y.z.min.js"></script>
 
     Note that in Jupyter Notebooks, it is not possible to use components and show in
     the same notebook cell.
@@ -144,10 +155,10 @@ def components(models, wrap_script=True, wrap_plot_info=True, theme=FromCurdoc):
                 }
 
         theme (Theme, optional) :
-            Defaults to the ``Theme`` instance in the current document.
-            Setting this to ``None`` uses the default theme or the theme
-            already specified in the document. Any other value must be an
-            instance of the ``Theme`` class.
+            Applies the specified theme when creating the components. If None,
+            or not specified, and the supplied models constitute the full set of
+            roots of a document, applies the theme of that document to the components.
+            Otherwise applies the default theme.
 
     Returns:
         UTF-8 encoded *(script, div[s])* or *(raw_script, plot_info[s])*
@@ -191,7 +202,7 @@ def components(models, wrap_script=True, wrap_plot_info=True, theme=FromCurdoc):
 
     # now convert dict to list, saving keys in the same order
     model_keys = None
-    dict_type = None
+    dict_type: Type[Dict[Any, Any]] = dict
     if isinstance(models, dict):
         model_keys = models.keys()
         dict_type = models.__class__
@@ -209,9 +220,8 @@ def components(models, wrap_script=True, wrap_plot_info=True, theme=FromCurdoc):
     bundle.add(Script(script_for_render_items(docs_json, [render_item])))
 
     script = bundle.scripts(tag=wrap_script)
-    script = encode_utf8(script)
 
-    def div_for_root(root):
+    def div_for_root(root: RenderRoot) -> str:
         return ROOT_DIV.render(root=root, macros=MACROS)
 
     if wrap_plot_info:
@@ -220,7 +230,7 @@ def components(models, wrap_script=True, wrap_plot_info=True, theme=FromCurdoc):
         results = render_item.roots
 
     # 3) convert back to the input shape
-
+    result: Any
     if was_single_object:
         result = results[0]
     elif model_keys is not None:
@@ -230,14 +240,14 @@ def components(models, wrap_script=True, wrap_plot_info=True, theme=FromCurdoc):
 
     return script, result
 
-def file_html(models,
-              resources,
-              title=None,
-              template=FILE,
-              template_variables={},
-              theme=FromCurdoc,
-              suppress_callback_warning=False,
-              _always_new=False):
+def file_html(models: Union[Model, Document, Sequence[Model]],
+              resources: Union[Resources, Tuple[JSResources, CSSResources]],
+              title: Optional[str] = None,
+              template: Union[Template, str] = FILE,
+              template_variables: Dict[str, Any] = {},
+              theme: ThemeLike = None,
+              suppress_callback_warning: bool = False,
+              _always_new: bool = False) -> str:
     ''' Return an HTML document that embeds Bokeh Model or Document objects.
 
     The data for the plot is stored directly in the returned HTML, with
@@ -266,10 +276,10 @@ def file_html(models,
             title, bokeh_js, bokeh_css, plot_script, plot_div
 
         theme (Theme, optional) :
-            Defaults to the ``Theme`` instance in the current document.
-            Setting this to ``None`` uses the default theme or the theme
-            already specified in the document. Any other value must be an
-            instance of the ``Theme`` class.
+            Applies the specified theme to the created html. If ``None``, or
+            not specified, and the function is passed a document or the full set
+            of roots of a document, applies the theme of that document.  Otherwise
+            applies the default theme.
 
         suppress_callback_warning (bool, optional) :
             Normally generating standalone HTML from a Bokeh Document that has
@@ -281,20 +291,23 @@ def file_html(models,
         UTF-8 encoded HTML
 
     '''
+
+    models_seq: Sequence[Model] = []
     if isinstance(models, Model):
-        models = [models]
+        models_seq = [models]
+    elif isinstance(models, Document):
+        models_seq = models.roots
+    else:
+        models_seq = models
 
-    if isinstance(models, Document):
-        models = models.roots
-
-    with OutputDocumentFor(models, apply_theme=theme, always_new=_always_new) as doc:
-        (docs_json, render_items) = standalone_docs_json_and_render_items(models, suppress_callback_warning=suppress_callback_warning)
-        title = _title_from_models(models, title)
+    with OutputDocumentFor(models_seq, apply_theme=theme, always_new=_always_new) as doc:
+        (docs_json, render_items) = standalone_docs_json_and_render_items(models_seq, suppress_callback_warning=suppress_callback_warning)
+        title = _title_from_models(models_seq, title)
         bundle = bundle_for_objs_and_resources([doc], resources)
         return html_page_for_render_items(bundle, docs_json, render_items, title=title,
                                           template=template, template_variables=template_variables)
 
-def json_item(model, target=None, theme=FromCurdoc):
+def json_item(model: Model, target: Optional[str] = None, theme: ThemeLike = None) -> Any: # TODO: TypedDict?
     ''' Return a JSON block that can be used to embed standalone Bokeh content.
 
     Args:
@@ -306,10 +319,10 @@ def json_item(model, target=None, theme=FromCurdoc):
             be supplied in the JavaScript call.
 
         theme (Theme, optional) :
-            Defaults to the ``Theme`` instance in the current document.
-            Setting this to ``None`` uses the default theme or the theme
-            already specified in the document. Any other value must be an
-            instance of the ``Theme`` class.
+            Applies the specified theme to the created html. If ``None``, or
+            not specified, and the function is passed a document or the full set
+            of roots of a document, applies the theme of that document.  Otherwise
+            applies the default theme.
 
     Returns:
         JSON-like
@@ -374,7 +387,7 @@ def json_item(model, target=None, theme=FromCurdoc):
 # Private API
 #-----------------------------------------------------------------------------
 
-def _check_models_or_docs(models):
+def _check_models_or_docs(models: Union[ModelLike, ModelLikeCollection]) -> ModelLikeCollection:
     '''
 
     '''
@@ -385,11 +398,11 @@ def _check_models_or_docs(models):
         models = [models]
 
     # Check for sequence
-    if isinstance(models, collections_abc.Sequence) and all(isinstance(x, (Model, Document)) for x in models):
+    if isinstance(models, Sequence) and all(isinstance(x, (Model, Document)) for x in models):
         input_type_valid = True
 
     if isinstance(models, dict) and \
-        all(isinstance(x, string_types) for x in models.keys()) and \
+        all(isinstance(x, str) for x in models.keys()) and \
         all(isinstance(x, (Model, Document)) for x in models.values()):
         input_type_valid = True
 
@@ -400,7 +413,7 @@ def _check_models_or_docs(models):
 
     return models
 
-def _title_from_models(models, title):
+def _title_from_models(models: Sequence[Union[Model, Document]], title: Optional[str]) -> str:
     # use override title
     if title is not None:
         return title
@@ -411,7 +424,7 @@ def _title_from_models(models, title):
             return p.title
 
     # use title from any model's document
-    for p in models:
+    for p in cast(Sequence[Model], models):
         if p.document is not None:
             return p.document.title
 
