@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -11,22 +11,16 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
 
-# Standard library imports
-
-# External imports
-
 # Bokeh imports
 from ..models.layouts import LayoutDOM
-from ..util.browser import get_browser_controller, NEW_PARAM
+from ..util.browser import NEW_PARAM, get_browser_controller
 from .notebook import run_notebook_hook
 from .saving import save
 from .state import curstate
@@ -43,7 +37,7 @@ __all__ = (
 # General API
 #-----------------------------------------------------------------------------
 
-def show(obj, browser=None, new="tab", notebook_handle=False, notebook_url="localhost:8888"):
+def show(obj, browser=None, new="tab", notebook_handle=False, notebook_url="localhost:8888", **kw):
     ''' Immediately display a Bokeh object or application.
 
         :func:`show` may be called multiple times in a single Jupyter notebook
@@ -117,6 +111,9 @@ def show(obj, browser=None, new="tab", notebook_handle=False, notebook_url="loca
     * The ``notebook_url`` parameter only applies when showing Bokeh
       Applications in a Jupyter notebook.
 
+    * Any additional keyword arguments are passed to :class:`~bokeh.server.Server` when
+      showing a Bokeh app (added in version 1.1)
+
     Returns:
         When in a Jupyter notebook (with ``output_notebook`` enabled)
         and ``notebook_handle=True``, returns a handle that can be used by
@@ -137,7 +134,7 @@ def show(obj, browser=None, new="tab", notebook_handle=False, notebook_url="loca
     # This ugliness is to prevent importing bokeh.application (which would bring
     # in Tornado) just in order to show a non-server object
     if is_application or callable(obj):
-        return run_notebook_hook(state.notebook_type, 'app', obj, state, notebook_url)
+        return run_notebook_hook(state.notebook_type, 'app', obj, state, notebook_url, **kw)
 
     return _show_with_state(obj, state, browser, new, notebook_handle=notebook_handle)
 
