@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -11,26 +11,35 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
 
-# Standard library imports
-
-# External imports
-
 # Bokeh imports
 from ..core.enums import MapType
 from ..core.has_props import abstract
-from ..core.properties import Bool, Enum, Float, Instance, Int, JSON, Override, String
+from ..core.properties import (
+    JSON,
+    Base64String,
+    Bool,
+    Enum,
+    Float,
+    Instance,
+    Int,
+    NonNullable,
+    Override,
+    String,
+)
 from ..core.validation import error, warning
+from ..core.validation.errors import (
+    INCOMPATIBLE_MAP_RANGE_TYPE,
+    MISSING_GOOGLE_API_KEY,
+    REQUIRED_RANGE,
+)
 from ..core.validation.warnings import MISSING_RENDERERS
-from ..core.validation.errors import INCOMPATIBLE_MAP_RANGE_TYPE, REQUIRED_RANGE, MISSING_GOOGLE_API_KEY
 from ..model import Model
 from ..models.ranges import Range1d
 from .plots import Plot
@@ -56,11 +65,11 @@ class MapOptions(Model):
 
     '''
 
-    lat = Float(help="""
+    lat = NonNullable(Float, help="""
     The latitude where the map should be centered.
     """)
 
-    lng = Float(help="""
+    lng = NonNullable(Float, help="""
     The longitude where the map should be centered.
     """)
 
@@ -79,7 +88,7 @@ class MapPlot(Plot):
         for r in ('x_range', 'y_range'):
             if r in kw and not isinstance(kw.get(r), Range1d):
                 raise ValueError('Invalid value for %r, MapPlot ranges may only be Range1d, not data ranges' % r)
-        super(MapPlot, self).__init__(*args, **kw)
+        super().__init__(*args, **kw)
 
     @error(INCOMPATIBLE_MAP_RANGE_TYPE)
     def _check_incompatible_map_range_type(self):
@@ -105,7 +114,7 @@ class GMapOptions(MapOptions):
     Whether the Google map should display its distance scale control.
     """)
 
-    styles = JSON(help="""
+    styles = NonNullable(JSON, help="""
     A JSON array of `map styles`_ to use for the ``GMapPlot``. Many example styles can
     `be found here`_.
 
@@ -131,6 +140,10 @@ class GMapPlot(MapPlot):
     e.g. ``(37.123, -122.404)``. It will be automatically converted into the
     web mercator projection to display properly over google maps tiles.
 
+    The ``api_key`` property must be configured with a Google API Key in order
+    for ``GMapPlot`` to function. The key will be stored in the Bokeh Document
+    JSON.
+
     Note that Google Maps exert explicit control over aspect ratios at all
     times, which imposes some limitations on ``GMapPlot``:
 
@@ -164,11 +177,20 @@ class GMapPlot(MapPlot):
 
     border_fill_color = Override(default="#ffffff")
 
-    api_key = String(help="""
+    api_key = NonNullable(Base64String, help="""
     Google Maps API requires an API key. See https://developers.google.com/maps/documentation/javascript/get-api-key
     for more information on how to obtain your own.
     """)
 
+    api_version = String(default="3.43", help="""
+    The version of Google Maps API to use. See https://developers.google.com/maps/documentation/javascript/versions
+    for more information.
+
+    .. note::
+        Changing this value may result in broken map rendering.
+
+    """)
+
     x_range = Override(default=lambda: Range1d())
 
     y_range = Override(default=lambda: Range1d())
