@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -19,9 +19,7 @@ associated value:
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
@@ -29,12 +27,10 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-import csv
 import codecs
+import csv
 import gzip
-import xml.etree.cElementTree as et
-
-# External imports
+import xml.etree.ElementTree as et
 
 # Bokeh imports
 from ..util.sampledata import package_path
@@ -70,7 +66,7 @@ def _read_data():
     with gzip.open(package_path('US_Regions_State_Boundaries.csv.gz')) as f:
         decoded = codecs.iterdecode(f, "utf-8")
         next(decoded)
-        reader = csv.reader(decoded, delimiter=str(','), quotechar=str('"'))
+        reader = csv.reader(decoded, delimiter=",", quotechar='"')
         for row in reader:
             region, name, code, geometry, dummy = row
             xml = et.fromstring(geometry)
