@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -12,19 +12,13 @@ Bokeh Documents and Sessions.
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
 
-# Standard library imports
-
-# External imports
-
 # Bokeh imports
 from ..util.serialization import make_id
 from ..util.tornado import _CallbackGroup
@@ -44,7 +38,7 @@ __all__ = (
 # Dev API
 #-----------------------------------------------------------------------------
 
-class SessionCallback(object):
+class SessionCallback:
     ''' A base class for callback objects associated with Bokeh Documents
     and Sessions.
 
@@ -101,7 +95,7 @@ class NextTickCallback(SessionCallback):
             id (str, optional) :
 
         '''
-        super(NextTickCallback, self).__init__(document, callback, id)
+        super().__init__(document, callback, id)
 
     def _copy_with_changed_callback(self, new_callback):
         ''' Dev API used to wrap the callback with decorators. '''
@@ -125,7 +119,7 @@ class PeriodicCallback(SessionCallback):
             id (str, optional) :
 
         '''
-        super(PeriodicCallback, self).__init__(document, callback, id)
+        super().__init__(document, callback, id)
         self._period = period
 
     @property
@@ -158,7 +152,7 @@ class TimeoutCallback(SessionCallback):
             id (str, optional) :
 
         '''
-        super(TimeoutCallback, self).__init__(document, callback, id)
+        super().__init__(document, callback, id)
         self._timeout = timeout
 
     @property
@@ -176,7 +170,7 @@ class TimeoutCallback(SessionCallback):
 # Private API
 #-----------------------------------------------------------------------------
 
-class _DocumentCallbackGroup(object):
+class _DocumentCallbackGroup:
     '''
 
     '''
