@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -72,6 +72,9 @@ class WSHandler(AuthMixin, WebSocketHandler):
 
         self._token = None
 
+        self._compression_level = kw.pop('compression_level', None)
+        self._mem_level = kw.pop('mem_level', None)
+
         # Note: tornado_app is stored as self.application
         super().__init__(tornado_app, *args, **kw)
 
@@ -158,6 +161,14 @@ class WSHandler(AuthMixin, WebSocketHandler):
         self._token = subprotocols[1]
         return subprotocols[0]
 
+    def get_compression_options(self):
+        if self._compression_level is None:
+            return None
+        options = {'compression_level': self._compression_level}
+        if self._mem_level is not None:
+            options['mem_level'] = self._mem_level
+        return options
+
     async def _async_open(self, token):
         ''' Perform the specific steps needed to open a connection to a Bokeh session
 
