@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -11,19 +11,15 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
 
-# Standard library imports
-import yaml
-
 # External imports
+import yaml
 
 # Bokeh imports
 from ..core.has_props import HasProps
@@ -53,7 +49,7 @@ __all__ = (
 # immutable object, because we share it among sessions and we
 # don't monitor it for changes. If you make this mutable by adding
 # any kind of setter, you could have to refactor some other code.
-class Theme(object):
+class Theme:
     ''' Provide new default values for Bokeh models.
 
     Bokeh Model properties all have some built-in default value. If a property
@@ -85,8 +81,13 @@ class Theme(object):
         has blocks for Model types to be themed. Each block has keys and
         values that specify the new property defaults for that type.
 
-        Here is an example theme in YAML format that sets various visual
-        properties for all figures, grids, and titles:
+        Take note of the fact that YAML interprets the value `None` as
+        a string, which is not usually what you want. To give `None` as a
+        value in YAML, use `!!null`. To give 'None' as a value in json,
+        use `null`.
+
+       Here is an example theme in YAML format that sets various visual
+       properties for all figures, grids, and titles:
 
         .. code-block:: yaml
 
@@ -95,6 +96,8 @@ class Theme(object):
                     background_fill_color: '#2F2F2F'
                     border_fill_color: '#2F2F2F'
                     outline_line_color: '#444444'
+                Axis:
+                    axis_line_color: !!null
                 Grid:
                     grid_line_dash: [6, 4]
                     grid_line_alpha: .3
@@ -112,6 +115,9 @@ class Theme(object):
                     'border_fill_color': '#2F2F2F',
                     'outline_line_color': '#444444',
                 },
+                'Axis': {
+                    'axis_line_color': null,
+                },
                 'Grid': {
                     'grid_line_dash': [6, 4]',
                     'grid_line_alpha': .3,
@@ -127,14 +133,11 @@ class Theme(object):
             raise ValueError("Theme should be constructed from a file or from json not both")
 
         if filename is not None:
-            f = open(filename)
-            try:
+            with open(filename) as f:
                 json = yaml.safe_load(f)
                 # empty docs result in None rather than {}, fix it.
                 if json is None:
                     json = {}
-            finally:
-                f.close()
 
         if json is None:
             raise ValueError("Theme requires json or a filename to construct")
