@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -234,9 +234,9 @@ def _round_hex(q: Any, r: Any) -> Tuple[Any, Any]:
     z = r
     y = -x-z
 
-    rx = np.round(x)
-    ry = np.round(y)
-    rz = np.round(z)
+    rx = np.round(x) # type: ignore[no-untyped-call]
+    ry = np.round(y) # type: ignore[no-untyped-call]
+    rz = np.round(z) # type: ignore[no-untyped-call]
 
     dx = np.abs(rx - x)
     dy = np.abs(ry - y)
